#include <cstdio>
#include <cmath>
#include <set>
#include <algorithm>
using namespace std;

const int		MAX_N			= 32;
const double	eps_sum		= 1e-2;
const double	eps			= 1e-9;

struct point { double x, y; };
struct triangle {
	int a, b, c;
	triangle(int _a, int _b, int _c) : a(_a), b(_b), c(_c) {
		if (b<a) swap(a,b);
		if (c<a) swap(a,c);
		if (b<c) swap(b,c);
	}
};

bool operator<(const triangle r, const triangle t) {
	return r.a!=t.a?r.a<t.a : r.b!=t.b?r.b<t.b : r.c<t.c;
}

// input file
int n;
point A[MAX_N];

// author's output file
double S_author;
set<triangle> T_author;

// contestant's output file
double S_contestant;
set<triangle> T_contestant;

int V[MAX_N];
int wrong=0;

void read_input (char *f)
{
	FILE *fin = fopen(f,"r");

	int i;

	fscanf (fin, "%d", &n);

	for (i=1; i<=n; i++)
		fscanf (fin, "%lf%lf", &A[i].x, &A[i].y);
	
	fclose (fin);
}

void read_output (char *f)
{
	FILE *fin = fopen(f,"r");

	int i, a, b, c;

	fscanf (fin, "%lf\n", &S_author);

	for (i=1; i<=n/3; i++) {
		fscanf (fin, "%d%d%d", &a, &b, &c);
		T_author.insert ( triangle(a,b,c) );
	}

	fclose (fin);
}

double surface (point &a, point &b, point &c)
{
	return fabs((b.x-a.x)*(c.y-b.y) - (c.x-b.x)*(b.y-a.y)) / 2.0;
}

void read_contestant_and_check (char *f)
{
	FILE *fin = fopen(f,"r");

	int i, a, b, c;
	double S, sum=0.0;

	fscanf (fin, "%lf\n", &S_contestant);

	if (S_contestant<0.0) {
		printf ("S<0\n");
		wrong=1;
	}

	for (i=1; i<=n/3; i++) {
		fscanf (fin, "%d%d%d\n", &a, &b, &c);
		if (a<0 || a>n || b<0 || b>n || c<0 || c>n) {
			printf ("Some points are not in [0;%d]\n", n);
			wrong=1;
		}
		if (V[a] || V[b] || V[c]) {
			printf ("Some points are the same\n");
			wrong=1;
		}
		V[a]=V[b]=V[c]=1;
		T_contestant.insert ( triangle(a,b,c) );
		
		S = surface(A[a],A[b],A[c]);
		if (S<eps) {
			printf ("Zero surface of triangle (%d,%d,%d)!\n", a, b, c);
			wrong=1;
		}
		sum += S;
	}

	if (fabs(S_author-S_contestant) > eps_sum) {
		//printf ("%lf %lf\n", sum, S_contestant);
		printf ("Not the same sum of the interfaces of the triangles and the number on the firse line!\n");
		wrong=1;
	}

	if (wrong) printf ("WRONG\n");
	else printf ("OK\n");

	fclose (fin);
}


int main (int argn, char* args[])
{
	if (argn!=4) {
		printf ("args: <IN file> <author's OUT file> <contestant's OUT file>\n");
		return 1;
	}
	
	read_input (args[1]);
	read_output (args[2]);
	read_contestant_and_check (args[3]);

	return 0;
}